API
===

.. module:: socketsundso

WebSocket Endpoint
-------------------------

.. automodule:: socketsundso.endpoints
   :members:
   :undoc-members:
   :show-inheritance:


Handler
-------------------------

.. automodule:: socketsundso.handler
   :members:
   :undoc-members:
   :show-inheritance:

Models
--------------------------

.. automodule:: socketsundso.models
   :members:
   :undoc-members:
   :show-inheritance:
